#include <cvidef.h>

/*======== ADVANTEST R3132 Series Spectrum Analyzers Include File ===========*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file         */
/*  instrument drivers.                                                      */
/*===========================================================================*/
     
#ifndef __avr3132s_HEADER
#define __avr3132s_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*===========================================================================*/
/* Instrument Specific Error Codes                                           */
/*===========================================================================*/
#define VI_ERROR_INSTR_FILE_OPEN              (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE             (_VI_ERROR+0x3FFC0801L)

#define VI_ERROR_INSTR_INTERPRETING_RESPONSE  (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9             (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10            (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11            (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12            (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13            (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14            (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15            (_VI_ERROR+0x3FFC080FL)

#define VI_WARNING_INSTR_OFFSET                         (0x3FFC0900L) 
#define VI_ERROR_INSTR_OFFSET                 (_VI_ERROR+0x3FFC0900L)

#define PREFIX_ERROR_INVALID_CONFIGURATION    (VI_ERROR_INSTR_OFFSET + 0xF0L)

#define VI_ERROR_MARKERINACTIVE               (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_SCANNING_FREQ_TABLE          (VI_ERROR_INSTR_OFFSET + 0x11L)
#define VI_ERROR_SCANNING_LEV_TABLE           (VI_ERROR_INSTR_OFFSET + 0x12L)

/*===========================================================================*/
/* CONSTANTS FOR instrFeatures STRUCTURE                                     */
/*===========================================================================*/
#define FREQUENCYLOW 1
#define FREQUENCYHIGH 2
#define SPANLOW 3
#define SPANHIGH 4
#define FREQOFFSETMIN 5
#define FREQOFFSETMAX 6
#define INPUTATTMIN 7
#define INPUTATTMAX 8
#define REFLEVELMIN 9
#define REFLEVELMAX 10
#define REFLEVELOFFSETMIN 11
#define REFLEVELOFFSETMAX 12
#define SWEEPTIMEMINI 13
#define SWEEPTIMEMAXI 14
#define GATEPOSITIONMINI 15
#define GATEPOSITIONMAXI 16
#define GATEWIDTHMINI 17
#define GATEWIDTHMAXI 18
#define AVERAGECOUNTMINI 19
#define AVERAGECOUNTMAXI 20
#define DLLEVELMIN 21
#define DLLEVELMAX 22
#define DISPLAYMODE 23
#define REFUNIT 24
#define SPAN 25
#define SCALE 26
#define DELTAYMIN 27
#define DELTAYMAX 28
#define CALLEVELMIN 29
#define CALLEVELMAX 30
#define MKRMSTATUS 31


/*===========================================================================*/
/* GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions)         */
/*===========================================================================*/
ViStatus _VI_FUNC avr3132s_init (ViRsrc resourceName,
                             ViBoolean IDquery,   
                             ViBoolean resetDevice,
                             ViPSession instrID);

ViStatus _VI_FUNC avr3132s_configRead(ViSession instrID,
                                  ViBoolean trace,
                                  ViInt16 peakSearch,
                                  ViInt16 _VI_FAR traceArray[],
                                  ViPReal64 sweepTime,
                                  ViChar _VI_FAR sweepUnit[],
                                  ViPReal64 MKRNposition,
                                  ViPReal64 MKRNlevel);

ViStatus _VI_FUNC avr3132s_Set_CenterFrequency (ViSession instrumentHandle,
                                            ViReal64 centerFrequency,
                                            ViBoolean CFStep,
                                            ViReal64 CFStepSize);

/* Frequency */                    
ViStatus _VI_FUNC avr3132s_Set_Span (ViSession instrID,
                                 ViInt16 spanType,
                                 ViReal64 spanValue);

ViStatus _VI_FUNC avr3132s_Set_StartStop (ViSession instrumentHandle,
                                      ViReal64 startFrequency,
                                      ViReal64 stopFrequency);

                                 
ViStatus _VI_FUNC avr3132s_Set_Freq (ViSession instrID,
                                 ViInt16 frequencyType,
                                 ViReal64 cntr_str,
                                 ViReal64 span_stp);

ViStatus _VI_FUNC avr3132s_Execute_TraceMath (ViSession instrumentHandle,
                                          ViInt16 operationModes);

ViStatus _VI_FUNC avr3132s_Set_MultiScreen (ViSession instrumentHandle,
                                        ViInt16 multiScreenMode,
                                        ViReal64 centerPosition,
                                        ViReal64 windowWidth,
                                        ViBoolean screenSide);

ViStatus _VI_FUNC avr3132s_Set_EMC (ViSession instrumentHandle,
                                ViInt16 EMCTraceDetection, ViInt16 QP_bandWidth,
                                ViInt16 antenna);

ViStatus _VI_FUNC avr3132s_Read_FreqSettings (ViSession instrID,
                                          ViInt16 frequencyParameter,
                                          ViPReal64 frequencyValue); 
                                          
ViStatus _VI_FUNC avr3132s_Set_FreqOffset (ViSession instrID,
									   ViBoolean activation,
                                       ViReal64 freqOffset);
                                       
ViStatus _VI_FUNC avr3132s_Read_FreqOffset (ViSession instrID,
										ViPInt16 status,
                                        ViPReal64 value);                                       
                 
ViStatus _VI_FUNC avr3132s_Set_FreqStepSize (ViSession instrID,
                                         ViBoolean controlType,
                                         ViReal64 frequencyStep);
                                         
ViStatus _VI_FUNC avr3132s_Read_FreqStepSize (ViSession instrID,
                                          ViPReal64 frequencyStepSize,
                                          ViPInt16 controlStatus);
                                          
ViStatus _VI_FUNC avr3132s_Set_FreqCounter (ViSession instrID,
                                        ViBoolean activation,
                                        ViInt16 resolution);                                          
                                          
ViStatus _VI_FUNC avr3132s_Read_FreqCounter (ViSession instrID,
                                         ViPInt16 counterStatus,
                                         ViPInt16 counterResolution, 
                                         ViPReal64 counterValue);                                         
                                         

ViStatus _VI_FUNC avr3132s_Set_FreqPreselector (ViSession instrumentHandle,
                                            ViBoolean peaking,
                                            ViInt16 peakingValue);

ViStatus _VI_FUNC avr3132s_set_HiSense (ViSession instrumentHandle,
                                    ViBoolean hiSense);

ViStatus _VI_FUNC avr3132s_Set_InputImpedance (ViSession instrumentHandle,
                                           ViBoolean inputImpedance);

ViStatus _VI_FUNC avr3132s_Set_CarrierChannel (ViSession instrumentHandle,
                                               ViInt16 carrierChannel);

ViStatus _VI_FUNC avr3132s_Set_CenterChannel (ViSession instrumentHandle,
                                              ViInt16 centerChannel);

ViStatus _VI_FUNC avr3132s_Set_StartStopChannel (ViSession instrumentHandle,
                                                 ViInt16 startChannel,
                                                 ViInt16 stopChannel);

ViStatus _VI_FUNC avr3132s_Set_FrequencyInput (ViSession instrumentHandle,
                                               ViInt16 inputType,
                                               ViReal64 startCHShift,
                                               ViReal64 stopCHShift);

ViStatus _VI_FUNC avr3132s_Edit_CHType1 (ViSession instrumentHandle,
                                         ViInt16 editTable,
                                         ViInt16 startChannelNumber,
                                         ViInt16 stopChannelNumber,
                                         ViReal64 startFrequency,
                                         ViReal64 channelSpacing,
                                         ViInt16 channelOffset);

ViStatus _VI_FUNC avr3132s_Set_CHType1 (ViSession instrumentHandle,
                                        ViBoolean table1, ViBoolean table2,
                                        ViBoolean table3);

ViStatus _VI_FUNC avr3132s_Edit_CHType2 (ViSession instrumentHandle,
                                         ViInt16 tableSize,
                                         ViInt16 channelNumber[],
                                         ViReal64 carrierFrequency[],
                                         ViReal64 startFrequency[],
                                         ViReal64 stopFrequency[]);

/* Amplitude */

ViStatus _VI_FUNC avr3132s_Set_RefLevel (ViSession instrID,
                                     ViReal64 refLevelValue);
                                     
ViStatus _VI_FUNC avr3132s_Read_RefLevel(ViSession instrID,
                                     ViPReal64 refLevelValue);

ViStatus _VI_FUNC avr3132s_Set_RefUnit (ViSession instrID,
                                    ViInt16 referenceUnit);
                                    
ViStatus _VI_FUNC avr3132s_Read_RefUnit (ViSession instrID,
                                     ViPInt16 referenceUnitNumber,
                                     ViChar _VI_FAR referenceUnitName[]);                                          

ViStatus _VI_FUNC avr3132s_Set_Scale (ViSession instrID,
                                  ViInt16 scale);
                                  
ViStatus _VI_FUNC avr3132s_Read_Scale (ViSession instrID,
                                   ViPInt16 status,
                                   ViChar _VI_FAR scaleName[]);
                                   
ViStatus _VI_FUNC avr3132s_Set_RefOffset (ViSession instrID,
                                      ViBoolean activation,
                                      ViReal64 offset);
                                      
ViStatus _VI_FUNC avr3132s_Read_RefLevelOffset (ViSession instrID,
                                            ViPReal64 value,
                                            ViPInt16 controlType);                                      
                                      
ViStatus _VI_FUNC avr3132s_Set_Att (ViSession instrID,
                                ViBoolean controlType,
                                ViReal64 value);
                                
ViStatus _VI_FUNC avr3132s_Read_Attenuation (ViSession instrID,
                                         ViPReal64 valuedB,
                                         ViPInt16 controlType);                                 
                                  
/* Bandwidth */

ViStatus _VI_FUNC avr3132s_Set_RBW (ViSession instrID,
                                ViInt16 RBWSetting);

ViStatus _VI_FUNC avr3132s_Set_VBW (ViSession instrID,
                                ViInt16 VBWSetting);

ViStatus _VI_FUNC avr3132s_Set_wideRBW (ViSession instrumentHandle,
                                        ViBoolean wideRBW);

ViStatus _VI_FUNC avr3132s_Set_All_Auto_Couple (ViSession instrID);

ViStatus _VI_FUNC avr3132s_Read_RBWandVBW (ViSession instrID,
                                       ViBoolean bandwidthtoRead,
                                       ViPReal64 bandwidthValue,
                                       ViPInt16 controlType);


ViStatus _VI_FUNC avr3132s_Set_AutoManual (ViSession instrumentHandle,
                                       ViInt16 contents, ViBoolean mode,
                                       ViReal64 manualValue);

/* Sweep & Trigger */

ViStatus _VI_FUNC avr3132s_Set_SweepTime (ViSession instrID,
                                      ViBoolean controlType,
                                      ViReal64 sweepTime);
                                       
ViStatus _VI_FUNC avr3132s_Set_SweepMode (ViSession instrID,
                                      ViBoolean sweepMode,
                                      ViBoolean windowSweep);
                                      
ViStatus _VI_FUNC avr3132s_Read_SweepTime (ViSession instrID,
                                       ViPReal64 timeValue,
                                       ViPInt16 controlType);
                                       
ViStatus _VI_FUNC avr3132s_Read_SweepMode (ViSession instrID,
                                       ViPInt16 sweepModeStatus,
                                       ViChar _VI_FAR sweepMode[]);
                                       
ViStatus _VI_FUNC avr3132s_Set_Trigger(ViSession instrID,
                                   ViInt16 source,
                                   ViBoolean polarity,
                                   ViInt16 videoLevel,
                                   ViReal64 externalLevel,
                                   ViBoolean trgDly,
                                   ViReal64 dlyTime);
                                   
ViStatus _VI_FUNC avr3132s_Set_TriggerTV(ViSession instrID,
									 ViInt16 triggerSource,
                                     ViBoolean triggerPolarity,
                                     ViInt16 lineNumber);
                                   
ViStatus _VI_FUNC avr3132s_Read_Trigger (ViSession instrID,
                                     ViPInt16 triggerStatus,
                                     ViChar _VI_FAR triggerName[],
                                     ViPInt16 triggerSlope,
                                     ViPReal64 triggerFeature); 

ViStatus _VI_FUNC avr3132s_Execute_XdBDown (ViSession instrumentHandle,
                                        ViInt16 dBDown);

ViStatus _VI_FUNC avr3132s_Execute_3rdOrder (ViSession instrumentHandle);

ViStatus _VI_FUNC avr3132s_Execute_AMModulation (ViSession instrumentHandle,
                                             ViBoolean AMMeas);

ViStatus _VI_FUNC avr3132s_Read_AMModulation (ViSession instrumentHandle,
                                          ViReal64 *AM);

ViStatus _VI_FUNC avr3132s_Take_Sweep (ViSession instrID,
                                   ViInt16 startSweep);                                     
                                     
/* Trace */

ViStatus _VI_FUNC avr3132s_Set_TraceMode (ViSession instrID,
                                      ViBoolean trace,
                                      ViInt16 traceMode,
                                      ViInt16 averageCount,
                                      ViBoolean averageMode);


ViStatus _VI_FUNC avr3132s_Set_TraceDetector (ViSession instrID,
                                          ViBoolean trace, 
                                          ViInt16 detectorMode);
                                          
ViStatus _VI_FUNC avr3132s_Read_TraceStatus (ViSession instrID,
                                         ViBoolean traceModetoRead,
                                         ViPInt16 traceModeStatus,
                                         ViChar generalStatusText[]);
                                         
ViStatus _VI_FUNC avr3132s_Read_DetectorMode (ViSession instrID,
                                          ViBoolean trace,
                                          ViPInt16 status,
                                          ViChar _VI_FAR detectorMode[]);
                                          
ViStatus _VI_FUNC avr3132s_Control_TraceAverage (ViSession instrID,
                                             ViBoolean trace,
                                             ViInt16 traceAverage);                                           
                                          
ViStatus _VI_FUNC avr3132s_Read_TraceData (ViSession instrID,
                                       ViBoolean tracetoRead,
                                       ViBoolean dataFormat,
                                       ViInt16 _VI_FAR traceDataArray[]);

ViStatus _VI_FUNC avr3132s_Write_TraceData (ViSession instrumentHandle,
                                        ViBoolean trace_toWrite,
                                        ViBoolean dataFormat,
                                        ViInt16 traceDataArray[]);

ViStatus _VI_FUNC avr3132s_Set_TracePoints (ViSession instrID,
										ViBoolean tracePoints); 
										
ViStatus _VI_FUNC avr3132s_Read_TracePoints (ViSession instrID,
										 ViPInt16 tracePoints);  										
                                         
/* Markers  */

ViStatus _VI_FUNC avr3132s_Read_MarkerStatus (ViSession instrID,
                                          ViPInt16 markerStatus,
                                          ViChar _VI_FAR markerStatusMessage[]);

ViStatus _VI_FUNC avr3132s_Set_NormalMarker (ViSession instrID,
                                         ViReal64 position);
                                         
ViStatus _VI_FUNC avr3132s_Set_DeltaMarker (ViSession instrID,
                                        ViReal64 position);
                                        
ViStatus _VI_FUNC avr3132s_Delete_AllMarkers (ViSession instrID) ;

ViStatus _VI_FUNC avr3132s_Delete_Multimarkers (ViSession instrID);

ViStatus _VI_FUNC avr3132s_Read_NormalMarker (ViSession instrID,
                                          ViPReal64 normalMarkerPosition,
                                          ViPReal64 normalMarkerLevel);
                                          
ViStatus _VI_FUNC avr3132s_Read_DeltaMarker (ViSession instrID,
                                         ViPReal64 deltaMarkerPosition,
                                         ViPReal64 deltaMarkerLevel,
                                         ViPReal64 normalMarkerPosition,
                                         ViPReal64 normalMarkerLevel);

ViStatus _VI_FUNC avr3132s_Set_XdBDown (ViSession instrumentHandle,
                                    ViReal64 dBDownWidth, ViInt16 MKRRead,
                                    ViBoolean contDown);

ViStatus _VI_FUNC avr3132s_Activate_Multimarkers (ViSession instrID);

ViStatus _VI_FUNC avr3132s_Set_Multimarkers (ViSession instrID,
										 ViInt16 multiMkrStatus[],
                                         ViReal64 multiMkrPositions[]);
                                         
ViStatus _VI_FUNC avr3132s_Set_ActiveMultimarker (ViSession instrID, ViInt16 index);

ViStatus _VI_FUNC avr3132s_Read_MultimarkersStatus (ViSession instrID,ViPInt16 status,
                                                                  ViChar _VI_FAR message[]);

ViStatus _VI_FUNC avr3132s_Read_Multimarkers (ViSession instrID,ViReal64 _VI_FAR MKRMpositions[10],
                                                            ViPReal64 MKRDposition,
                                                            ViReal64 _VI_FAR MKRMlevels[10],
                                                            ViPReal64 MKRDlevel);

ViStatus _VI_FUNC avr3132s_Read_MultimarkerActive (ViSession instrID, ViPInt16 index); 

ViStatus _VI_FUNC avr3132s_Set_MarkerOptions (ViSession instrID,
                                          ViBoolean stepstatus,
                                          ViReal64 stepvalue,       
                                          ViBoolean fixed,
                                          ViBoolean couple);
                                          
ViStatus _VI_FUNC avr3132s_Read_MarkerOptions (ViSession instrID,
                                           ViPInt16 markerStepControl,
                                           ViPReal64 markerStepValue,
                                           ViPInt16 fixedMarkerStatus,
                                           ViChar _VI_FAR fixedMarkerMessage[],
                                           ViPInt16 coupleMarkerStatus,
                                           ViChar _VI_FAR coupleMarkerMessage[]);                                          
                                                           
ViStatus _VI_FUNC avr3132s_Set_MarkerTrace (ViSession instrID,
                                        ViBoolean markerTrace);
                                        
ViStatus _VI_FUNC avr3132s_Read_MarkerTraceStatus (ViSession instrID,
                                               ViPInt16 markerTraceStatus,
                                               ViChar _VI_FAR markerTraceMessage[]);                                        

    
/* Peak Search */

ViStatus _VI_FUNC avr3132s_Set_PeakSearchOptions (ViSession instrID,
                                              ViBoolean continuousSearch, 
                                              ViBoolean signalTrack,
                                              ViInt16 peakRange,
                                              ViReal64 deltaY);
                                              
ViStatus _VI_FUNC avr3132s_Read_PeakSearchOptions (ViSession instrID,
                                               ViPInt16 contPeakStatus,
                                               ViPInt16 signalTrackStatus,
                                               ViPReal64 deltaY);                                              

ViStatus _VI_FUNC avr3132s_Set_Annotation (ViSession instrumentHandle,
                                       ViBoolean annotation);

ViStatus _VI_FUNC avr3132s_Set_MixerPara (ViSession instrumentHandle,
                                          ViBoolean mixer, ViInt16 bandN,
                                          ViBoolean bandLock, ViBoolean AVGLoss,
                                          ViReal64 AVGLossValue,
                                          ViBoolean loss_vsFreq);

ViStatus _VI_FUNC avr3132s_Set_EXTMixerLoss (ViSession instrumentHandle,
                                             ViInt16 tableSize,
                                             ViReal64 frequency[],
                                             ViReal64 lvlMinus[],
                                             ViReal64 lvlPlus[]);

ViStatus _VI_FUNC avr3132s_Search_Peak (ViSession instrID,
                                    ViInt16 searchType,
                                    ViPReal64 deltaPosition,
                                    ViPReal64 deltaLevel);

ViStatus _VI_FUNC avr3132s_PeakList (ViSession instrumentHandle,
								 ViInt16 peakListMode, ViInt16 *numPkList,
                                 ViReal64 frequency[], ViReal64 level[],
                                 ViInt16 *levelUnits);

ViStatus _VI_FUNC avr3132s_Execute_PeakTo (ViSession instrID,
                                       ViBoolean peakTo);
                                       
ViStatus _VI_FUNC avr3132s_Execute_DeltaMarkerTo (ViSession instrID,
                                  		          ViInt16 deltaTo);
                                         
ViStatus _VI_FUNC avr3132s_Execute_NormalMarkerTo (ViSession instrID,
                                           		   ViInt16 normalTo);                                        
                                          

ViStatus _VI_FUNC avr3132s_Set_Gate (ViSession instrumentHandle,
                                 ViReal64 gatePosition, ViReal64 gateWidth,
                                 ViBoolean gateSlope, ViInt16 gateSource,
                                 ViReal64 EXTTriggerLevel, ViInt16 TVHNumber,
                                 ViBoolean externalGateIn, ViBoolean gatedSweep);

/* Measurement Window */

ViStatus _VI_FUNC avr3132s_Set_MeasurementWindow (ViSession instrID,
                                              ViBoolean windowStatus,
                                              ViReal64 Xcenterposition,
                                              ViReal64 Xwidth);
                                              
ViStatus _VI_FUNC avr3132s_Read_MeasurementWindow (ViSession instrID,
                                               ViPInt16 status,
                                               ViChar _VI_FAR message[],
                                               ViPReal64 Xposition,
                                               ViPReal64 Xwidth); 
                                               
/* display and reference lines */

ViStatus _VI_FUNC avr3132s_Set_DisplayLine (ViSession instrID,
                                        ViBoolean showDL,
                                        ViReal64 DLposition);

ViStatus _VI_FUNC avr3132s_Read_DisplayLine (ViSession instrID,
                                         ViPInt16 status,
                                         ViChar _VI_FAR message[],
                                         ViPReal64 level);

ViStatus _VI_FUNC avr3132s_Set_ReferenceLine (ViSession instrID,
                                          ViBoolean showRefLine,
                                          ViReal64 refLineLevel);
                                          
ViStatus _VI_FUNC avr3132s_Read_ReferenceLine(ViSession instrID,
                                          ViPInt16 status,
                                          ViChar _VI_FAR message[],
                                          ViPReal64 level);
                                          
/* Limit UP and LOW - Level Window */

ViStatus _VI_FUNC avr3132s_Set_LimitLines (ViSession instrID, ViBoolean limitLine,
                                       ViInt16 tblSize, 
                                       ViReal64 *xTbl, ViReal64 *yTbl,
                                       ViReal64 sftX, ViReal64 sftY);

ViStatus _VI_FUNC avr3132s_Activate_LimitLine (ViSession instrID,ViBoolean LL1Status,
                                                             ViBoolean LL2Status,
                                                             ViInt16 XpositionMode,
                                                             ViInt16 YpositionMode,
                                                             ViBoolean passfail);
                                                             
ViStatus _VI_FUNC avr3132s_Read_LLjudgment (ViSession instrumentHandle,
                                        ViInt16 judgementOperation,
                                        ViInt16 *judgementStatus,
                                        ViChar judgement[],
                                        ViInt16 *no_ofFailPoints,
                                        ViReal64 frequencyFailPoints[],
                                        ViReal64 level_ofFailPoints[]);

ViStatus _VI_FUNC avr3132s_Read_LLstatus (ViSession instrID, ViBoolean parameter,
                                      					 ViPInt16 status,
                                      					 ViChar _VI_FAR message[]);
                                      
ViStatus _VI_FUNC avr3132s_Read_LLoptions (ViSession instrID, ViPInt16 XpositionMode,
                                       					  ViPInt16 YpositionMode);                                      

ViStatus _VI_FUNC avr3132s_Set_LimitUPandLOW (ViSession instrID, ViBoolean windowStatus,
                                          					 ViReal64 lowerlimit,
                                          					 ViReal64 upperlimit);
                                          
ViStatus _VI_FUNC avr3132s_Read_LimitUPandLOW (ViSession instrID, ViPInt16 status,
                                           					  ViChar _VI_FAR message[],
                                           					  ViPReal64 lowerLevel,
                                           					  ViPReal64 upperLevel);                                          
                                          
                                          
ViStatus _VI_FUNC avr3132s_Read_LimitUPandLOW_Judgment (ViSession instrID, ViPInt16 result,
                                                    				   ViChar _VI_FAR message[]);
                                                             
/* Utility */

ViStatus _VI_FUNC avr3132s_Calibration (ViSession instrID,
                                    ViInt16 elementtoCalibrate,
                                    ViReal64 calibrationLevel,
                                    ViBoolean calibrationCorrection,
                                    ViBoolean frequencyCorrection);
                                    
ViStatus _VI_FUNC avr3132s_Execute_AutoTuning (ViSession instrSession);                                    
                                    
ViStatus _VI_FUNC avr3132s_Display_Label (ViSession instrID,
                                      ViBoolean showLabel,
                                      ViString label);

ViStatus _VI_FUNC avr3132s_Read_StatusByte (ViSession instrID,
                                        ViPInt16 statusByteRead);
                                          
ViStatus _VI_FUNC avr3132s_Clear_StatusByte (ViSession instrID);                                          

/* Frequency or Time Conversion */

ViStatus _VI_FUNC avr3132s_Convert_Frequency (ViSession instrID,
                                          ViReal64 inputFrequencyValue,
                                          ViPReal64 outputFrequencyValue,
                                          ViChar _VI_FAR frequencyUnit[]);
                                          
ViStatus _VI_FUNC avr3132s_Convert_Time (ViSession instrID,
                                     ViReal64 inputTimeValue,
                                     ViPReal64 outputTimeValue,
                                     ViChar _VI_FAR timeUnit[]);
                                     
/* Power Measurement */

ViStatus _VI_FUNC avr3132s_Execute_PowerMeasurement (ViSession instrID,
                                             ViInt16 powerMeasurement,
                                             ViInt16 averagingCount);
                                             
ViStatus _VI_FUNC avr3132s_Read_PowerMeasurement (ViSession instrID,
                                              ViInt16 power,
                                              ViPReal64 powerValue,
                                              ViPInt16 averagingCount);                                          

ViStatus _VI_FUNC avr3132s_Execute_ACP_R3131 (ViSession instrumentHandle,
                                              ViReal64 channelBandWidth,
                                              ViReal64 channelSpace1,
                                              ViBoolean selectChannelSpace2,
                                              ViReal64 channelSpace2,
                                              ViBoolean ACPGraph,
                                              ViBoolean ACPMeas);

ViStatus _VI_FUNC avr3132s_Execute_ACP_R3132s (ViSession instrumentHandle,
                                               ViReal64 carrierBandWidth,
                                           	   ViInt16 ACPTableSize,
                                           	   ViReal64 ACPCS[], ViReal64 ACPBS[],
                                           	   ViBoolean rootNyquistFilter,
                                           	   ViReal64 symbolRate,
                                          	   ViReal64 rolloffFactor,
                                          	   ViBoolean BSWindow, ViInt16 ACPScreen,
                                          	   ViBoolean ACPGraph, ViBoolean ACPMeas);

ViStatus _VI_FUNC avr3132s_Read_ACP_R3131 (ViSession instrumentHandle,
                                           ViBoolean selectChannelSpace2,
                                           ViReal64 *power_ofLowerChannel1,
                                           ViReal64 *power_ofUpperChannel1,
                                           ViReal64 *power_ofLowerChannel2,
                                           ViReal64 *power_ofUpperChannel2);

ViStatus _VI_FUNC avr3132s_Read_ACP_R3132s (ViSession instrumentHandle,
                                            ViReal64 *referencePower,
                                            ViInt16 *number_ofACPData,
                                            ViReal64 lowerFrequency[],
                                            ViReal64 level_ofLowerFrequency[],
                                            ViReal64 upperFrequency[],
                                            ViReal64 level_ofUpperFrequency[]);

ViStatus _VI_FUNC avr3132s_Execute_OBWMeasurement (ViSession instrumentHandle,
                                           ViReal64 OBW, ViBoolean OBWMeas);

ViStatus _VI_FUNC avr3132s_Read_OBWMeasurement (ViSession instrumentHandle,
                                            ViReal64 *OBW,
                                            ViReal64 *centerFrequency,
                                            ViReal64 *OBWValue);

ViStatus _VI_FUNC avr3132s_Set_Sound (ViSession instrumentHandle, ViInt16 soundMode,
                                  ViInt16 volume, ViReal64 pauseTime,
                                  ViBoolean squelchMode, ViReal64 squelchValue);

ViStatus _VI_FUNC avr3132s_Execute_SpectrumMask (ViSession instrumentHandle,
                                                 ViReal64 carrierBandWidth,
                                                 ViInt16 CSBSTableSize,
                                                 ViReal64 CS[], ViReal64 BS[],
                                                 ViBoolean rootNyquistFilter,
                                                 ViReal64 symbolRate,
                                                 ViReal64 rolloffFactor,
                                                 ViBoolean resultDisplayMode,
                                                 ViBoolean windowBS,
                                                 ViBoolean measurement);

ViStatus _VI_FUNC avr3132s_Execute_Spurious (ViSession instrumentHandle,
                                             ViBoolean measurementMode,
                                             ViInt16 tableNo, ViInt16 tableSize,
                                             ViReal64 startFrequency[],
                                             ViReal64 stopFrequency[],
                                             ViReal64 centerFrequency[],
                                             ViReal64 RBW[],
                                             ViReal64 sweepTime[],
                                             ViReal64 limitLevel[],
                                             ViInt16 sweepCountTimes,
                                             ViBoolean passJudge,
                                             ViBoolean measurement);

ViStatus _VI_FUNC avr3132s_Execute_NoiseHz (ViSession instrumentHandle,
                                    ViInt16 noiseHzMode, ViReal64 noiseFreq);

ViStatus _VI_FUNC avr3132s_Read_SpectrumMask (ViSession instrumentHandle,
                                              ViReal64 *referencePower,
                                              ViInt16 *number_ofData,
                                              ViReal64 lowerFrequency[],
                                              ViReal64 level_ofLowerFrequency[],
                                              ViReal64 upperFrequency[],
                                              ViReal64 level_ofUpperFrequency[]);

ViStatus _VI_FUNC avr3132s_Read_Spurious (ViSession instrumentHandle,
                                          ViInt16 *measuremwentPoints,
                                          ViInt16 number_ofSpuriousSignals[],
                                          ViReal64 spuriousFrequency[],
                                          ViReal64 spuriousLevel[],
                                          ViInt16 judgement_result[]);

ViStatus _VI_FUNC avr3132s_Read_NoiseHz (ViSession instrumentHandle,
                                     ViReal64 *powerOutput);

/* Data Management */
ViStatus _VI_FUNC avr3132s_Save_File (ViSession instrID,
                                  ViBoolean drive,
                                  ViInt16 registerNumber,
                                  ViString fileName);
                                  
ViStatus _VI_FUNC avr3132s_Save_FileOptions (ViSession instrumentHandle,
                                         ViBoolean setupConditions,
                                         ViBoolean traceData,
                                         ViBoolean antennaCorrections,
                                         ViBoolean normCorr,
                                         ViBoolean traceLevel,
                                         ViInt16 limitLines,
                                         ViBoolean lossFreq,
                                         ViBoolean channel,
                                         ViBoolean spurious);                               

ViStatus _VI_FUNC avr3132s_Recall_File (ViSession instrID,
                                    ViBoolean drive,
                                    ViInt16 registerNumber,
                                    ViString fileName);
                                    
ViStatus _VI_FUNC avr3132s_Delete_File (ViSession instrID,
                                    ViBoolean drive,
                                    ViInt16 registerNumber,
                                    ViString fileName);
                                    
ViStatus _VI_FUNC avr3132s_Copy_Bitmap_R3131 (ViSession instrID,
                                    	  ViBoolean deviceSelection,
                                    	  ViInt16 printerSelection,
                                    	  ViBoolean copyMode,
                                    	  ViBoolean copySize);
                                    
ViStatus _VI_FUNC avr3132s_Copy_Bitmap_R3132s (ViSession instrumentHandle,
                                           ViBoolean deviceSelection,
                                           ViInt16 printerSelection,
                                           ViInt16 printMode,
                                           ViInt16 BMPOutputMode,
                                           ViBoolean fileCompression,
                                           ViInt16 fileNumber);

/* Antenna Factor Correction */
ViStatus _VI_FUNC avr3132s_Set_UserAntennaCorrection (ViSession instrID,
                                                  ViBoolean antennaCorrection,
                                                  ViBoolean correctionType,
                                                  ViReal64 corrFreqTable[],
                                                  ViReal64 corrLevelTable[]);
                                                  
ViStatus _VI_FUNC avr3132s_Set_MarketAntennaCorrection (ViSession instrID,
                                                    ViInt16 antennaType);
                                                    
ViStatus _VI_FUNC avr3132s_Read_AntennaCorrectionStatus (ViSession instrID,
                                                     ViPInt16 status,
                                                     ViChar _VI_FAR message[]);
                                                     
/* Tracking Generator */

ViStatus _VI_FUNC avr3132s_Set_TGstatus (ViSession instrID,
									 ViBoolean status,
									 ViReal64 level);
									 
ViStatus _VI_FUNC avr3132s_Read_TGstatus (ViSession instrID,
                                      ViPInt16 status,
                                      ViChar _VI_FAR message[],
                                      ViPReal64 level);
                                      
ViStatus _VI_FUNC avr3132s_Set_TGfreqComp (ViSession instrID, 
									   ViBoolean compType,
									   ViReal64 freqCompValue);
									   
ViStatus _VI_FUNC avr3132s_Read_TGfreqComp (ViSession instrID,
										ViPReal64 freqComp);
										
ViStatus _VI_FUNC avr3132s_Set_TGnormFunction (ViSession instrID,
										   ViInt16 normChoice);	
										   
ViStatus _VI_FUNC avr3132s_Read_TGnormFunction (ViSession instrID,
                                      		ViPInt16 status,
                                      		ViChar _VI_FAR message[]);										   
						
/* Standard Utility Functions */

ViStatus _VI_FUNC avr3132s_Write_InstrData (ViSession instrID,
                                        ViString writeBuffer);

ViStatus _VI_FUNC avr3132s_Read_InstrData (ViSession instrID,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
                                      
ViStatus _VI_FUNC avr3132s_reset (ViSession instrSession);
                              
ViStatus _VI_FUNC avr3132s_selfTest (ViSession instrID,
                                 ViPInt16 selfTestResult,
                                 ViChar _VI_FAR selfTestMessage[]);
                                 
ViStatus _VI_FUNC avr3132s_errorQuery (ViSession instrID,
                                   ViPInt32 errorCode,
                                   ViChar _VI_FAR errorMessage[]);
                                   
ViStatus _VI_FUNC avr3132s_errorMessage (ViSession instrID,
                                     ViStatus statusCode,
                                     ViChar _VI_FAR message[]);
                                     
ViStatus _VI_FUNC avr3132s_revisionQuery (ViSession instrID,
                                      ViChar _VI_FAR instrumentDriverRevision[],
                                      ViChar _VI_FAR firmwareRevision[]);                           
                           
ViStatus _VI_FUNC avr3132s_close (ViSession instrID);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*===========================================================================*/
/* END INCLUDE FILE                                                          */
/*===========================================================================*/

#endif
